#!/usr/bin/env node

const bin = require("./bin");

bin.run("hurl");